@@ -208,6 +208,7 @@ class Emptor(object):
             Hats = list of response default http accept type strings ('xml', 'json','html', 'text')
             
             Preloads = default request data, dict or list of key, value duples
+            Qkeys = default query arg keys
             Headers = default request headers, dict or list of key, value duples
             Creds = optional default dict with keys name password and domain used for authentication
             Xmlns = optional list of default xml namespace urls that is used when reaping xml content
@@ -309,7 +310,8 @@ class Emptor(object):
     Domain =  'localhost' # url request host domain  url netloc is domain:port
     Port = '' # url request port
     Prefix = '/' # url path prefix
-    Preloads =  ODict() #default data dict preload
+    Preloads =  ODict() #d efault data dict preload
+    Qkeys = [] # list of default query arg keys
     Headers = LODict() # default headers lower cased dict
     Hrm = 'GET' # default request method
     Hct = 'text' # default content type
@@ -356,8 +358,8 @@ class Emptor(object):
               mdp = mold directory path
               pkcp = private key and cert path
               cacp = cert auth path or False if ignore
-              debug = create trace
               red = allow redirects
+              debug = create trace
               
         """
         # optional parameters, 
@@ -425,10 +427,10 @@ class Emptor(object):
             self.reaper = self.reap #use default reaper
         
         self.mold = mold
-                
-        if qkeys is None:
-            qkeys = []        
-        self.qkeys = list(qkeys) #make local copy
+        
+        self.qkeys = list(self.Qkeys) # make local copy of defaults       
+        if qkeys is not None:
+            self.qkeys = list(set(self.qkeys + qkeys)) #merge unique keys
         
         if pkeys is None:
             pkeys = []        
@@ -608,9 +610,9 @@ class Emptor(object):
             Body is string concated from all string positional arguments.
             Non string positional arguments and keyword arguments are ignored.
             
-            Data is an ordereddict where the items are extracted from the
-            any sequenced duples and/or dicts in the positonal arguments and from
-            the keyword arguments.
+            Data is an ordereddict where the items are extracted from
+            self.preloads, any sequenced duples and/or dicts in the positonal
+            arguments, and from the keyword arguments.
             String positional arguments are ignored.
         """
         body = ''
@@ -868,7 +870,7 @@ class Emptory(object):
                    suffix='', preloads=None, headers=None, 
                    hrm='', hct='',hscs=None, hats=None,
                    creds=None, xmlns=None, mdp='', pkcp='', cacp=False,
-                   debug=False,  red=True):
+                   red=True,  debug=False,  ):
         """ Generate emptor init args for the given entry and init parameters. 
             Parameters
                 scheme = Server URL scheme
@@ -887,8 +889,8 @@ class Emptory(object):
                 mdp = mold directory path
                 pkcp = private key cert path
                 cacp = certificate authority certs path
-                debug = create and save httplib trace
                 red = allow redirects
+                debug = create and save httplib trace
                 
             Special processing of parameters to this function
                 The final instance attributes value will be.
@@ -923,8 +925,8 @@ class Emptory(object):
                 'bkeys' optional
                 'pkcp' optional
                 'cacp' optional
-                'debug' optional
                 'red' optional
+                'debug' optional
                 
                 
                     
@@ -946,8 +948,9 @@ class Emptory(object):
         ia['mdp'] = entry.get('mdp', '') or mdp
         ia['pkcp'] = entry.get('pkcp', '') or pkcp
         ia['cacp'] = entry.get('cacp', False) or cacp
-        ia['debug'] = entry.get('debug', False) or debug
         ia['red'] = entry.get('red', False) or red
+        ia['debug'] = entry.get('debug', False) or debug
+        
         #service specific
         ia['suffix'] = entry.get('suffix', '')
         ia['mold'] = entry.get('mold', '')  
